#
# spec file for package capnproto
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libver 0_10_4
Name:           capnproto
Version:        0.10.4
Release:        1.3
Summary:        A Data Serialization Format
License:        MIT
URL:            https://capnproto.org
Source:         https://capnproto.org/capnproto-c++-%{version}.tar.gz
BuildRequires:  cmake
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7-c++
%endif
BuildRequires:  pkgconfig
Requires:       libcapnp-%{_libver} = %{version}

%description
Cap'n Proto is a binary data interchange format and capability-based
RPC system.

%package     -n libcapnp-%{_libver}
Summary:        The Cap'n Proto data serialization library
Conflicts:      libcapnp-0_9 = 0.9.1

%description -n libcapnp-%{_libver}
Cap'n Proto is a binary data interchange format and capability-based
RPC system.

This package provides runtime libraries for capnproto.

%package     -n libcapnp-devel
Summary:        Development headers for the Cap'n Proto C++ Library
Requires:       libcapnp-%{_libver} = %{version}

%description -n libcapnp-devel
Cap'n Proto is a binary data interchange format and capability-based
RPC system.

This package provides development headers for capnproto.

%prep
%autosetup -n %{name}-c++-%{version}

%build
export CXX=g++
test -x "$(type -p g++-7)" && export CXX=g++-7
%configure
%make_build

%install
%make_install
find %{buildroot}%{_libdir} -type f \( -name "*.a" -o -name "*.la" \) -delete -print

%post -n libcapnp-%{_libver} -p /sbin/ldconfig
%postun -n libcapnp-%{_libver} -p /sbin/ldconfig

%files
%license LICENSE.txt
%doc README.txt
%{_bindir}/capnp
%{_bindir}/capnpc
%{_bindir}/capnpc-c++
%{_bindir}/capnpc-capnp

%files -n libcapnp-%{_libver}
%{_libdir}/libcapnp-%{version}.so
%{_libdir}/libcapnp-rpc-%{version}.so
%{_libdir}/libcapnpc-%{version}.so
%{_libdir}/libcapnp-json-%{version}.so
%{_libdir}/libcapnp-websocket-%{version}.so
%{_libdir}/libkj-test-%{version}.so
%{_libdir}/libkj-%{version}.so
%{_libdir}/libkj-async-%{version}.so
%{_libdir}/libkj-http-%{version}.so

%files -n libcapnp-devel
%{_includedir}/capnp
%{_includedir}/kj
%{_libdir}/libcapnp-rpc.so
%{_libdir}/libcapnp.so
%{_libdir}/libcapnpc.so
%{_libdir}/libcapnp-json.so
%{_libdir}/libcapnp-websocket.so
%{_libdir}/libkj-test.so
%{_libdir}/libkj-async.so
%{_libdir}/libkj-http.so
%{_libdir}/libkj.so
%dir %{_libdir}/cmake/CapnProto
%{_libdir}/cmake/CapnProto/CapnProtoConfig.cmake
%{_libdir}/cmake/CapnProto/CapnProtoConfigVersion.cmake
%{_libdir}/cmake/CapnProto/CapnProtoMacros.cmake
%{_libdir}/cmake/CapnProto/CapnProtoTargets.cmake
%{_libdir}/pkgconfig/capnp.pc
%{_libdir}/pkgconfig/capnpc.pc
%{_libdir}/pkgconfig/capnp-json.pc
%{_libdir}/pkgconfig/capnp-rpc.pc
%{_libdir}/pkgconfig/capnp-websocket.pc
%{_libdir}/pkgconfig/kj-async.pc
%{_libdir}/pkgconfig/kj-gzip.pc
%{_libdir}/pkgconfig/kj-http.pc
%{_libdir}/pkgconfig/kj-test.pc
%{_libdir}/pkgconfig/kj-tls.pc
%{_libdir}/pkgconfig/kj.pc

%changelog
* Thu Apr 13 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.4
  * Clarify doc on absolute path imports
* Wed Nov 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.3
  * Fix CVE-2022-46149: Possible out-of-bounds read related to
    list-of-pointers
* Thu Jun 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.2
  * cmake: adding src/ include path to build
  * Allow unused parameter in KJ_STRINGIFY
  * Add List::addFront().
  * Don't use deprecated std::iterator
  * using absolute includes across library boundary
  * Add kj::VectorOutputStream::clear()
  * Mention map() and orDefault() in KJ tour
  * Fix ASAN problems under Clang 15.
  * Add header guards to all headers that were missing them.
  * Support permessage-deflate WebSocket Extension
  version 0.10.1:
  * Add missing header to makefiles.
* Fri Jun  3 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.0
  * Introduce a debugging aid to detect when KJ I/O objects are
    held in the wrong places.
  * Support OneOf for up to 50 variants
  * Rename AnyPointer -> Capability
  * Fix async-test.c++ unused function warnings
  * Fix linux-musl build
  * Work around getcontext() being broken on manylinux2014-x86.
  * CI: alpine needs bash to run the tests
  * Implement lazy Maybe<Own<T>>::orDefault
  * Move countLines() inside if pragma
  * Update outdated references to Sandstorm.
  * Fix release tests
  * Make threads move-constructible and move-assignable
  * Allow changing an exception's description
  * Fix bug in TreeIndex erase().
  * Fix CapabilityServerSet<DynamicCapability>.
  * Docs: correct target of parameter annotation
  * allow defer to be cancelled
  * Add SchemaParser::getAllLoaded() to get all parsed schemas.
  * Add comment clarifying how to get unindexed headers
  * Fix computeCurrentPath test with generic Unix test
  * add popFront to ProducerConsumerQueue
  * 1429: Make kj-test target build conditionally
  * Check ERANGE error from getcwd
  * Fix windows-sanity.h in NOGDI case, again.
  * Fix typo in section about KJ
  * Fix release tests
  * Fix bug with queue wait time metrics in TwoPartyNetwork
  * Make sure to clean up properly with a pipe hits an exception
    to avoid inadvertently hanging
  * Add dockcross/manylinux2014 to tests
  * Check if SYS_renameat2 defined before using it
  * CMake: don't overwrite tls-test.c++ COMPILE_DEFINITIONS,
    append to it
  * Assert that HttpHeaders instances know about indexed ids
  * Disable the coroutine immediately-ready optimization before
    the first suspension
  * Add support for musl
  * Build fails with -O0 on Ubuntu 20.04
  * 0.10
  * Fix bug where HttpServer listen loop would terminate early.
  * Fix corruption in Tables with a TreeIndex after clear()
  * HTTP concurrency limiter: Avoid unnecessary recursion
  * Restore splice pump optimization
  * Revert "Optimize fd-to-fd pumps on Linux using splice()."
  * Fix typos
  * Optimize fd-to-fd pumps on Linux using splice().
  * Fix obscure FD leak... and disable Cygwin CI
  * Update old repo url with new
  * Introduce ConnectionReceiver implementation that aggregates
    from multiple underlying receivers.
  * kj-http: Fix memory leak caused by TCO breakage
  * Lie about the true size of the fiber stack on M1 Macs
  * Log exceptions when serving HTTP errors by default
  * Fix tryTee() optimization when limits are used.
  * Fix/refactor AsyncTee
  * Tweak BTreeImpl::verifyNode().
  * Replace boolean destroyed with magic integer live in Event.
  * Work around old OpenSSL versions not being able to verify
    Let's Encrypt certificate chains.
  * Fix async-io-win32 for vs2019 & C++20
  * Track source locations where Events were created in order to
    provide extra debugging info.
  * Fix an irrelevant bug in BTreeIndex.
  * Fix Potential UAF caused by race in MembraneHook
  * refcount from zero instead of one
  * Add debugging to detect UAF of Event.
  * Report next expected ordinal when duplicate ordinals are
    found
  * Correct documentation of Maybe regarding contruction from T*
  * LocalResponse refcount is never used
  * Move BUILD_TESTING to root
  * Fix HttpServer::drain() data loss race condition.
  * Try harder to work around windows.h defining min()/max() as
    macros.
  * Fixes the double includes in build when ZLIB is found.
  * Improve TLS accept error handling
  * Add KJ_UNWRAP_OR_RETURN macro.
  * Make hashCode behave more consistently
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Employ shared lib packaging guideline and resolve this rpmlint
  report: "libcapnp-0_9.x86_64: E: shlib-policy-name-error
  SONAME: libkj-0.9.1.so, expected package suffix: 0_9_1"
* Sun Sep 26 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.1
  * only import fiber related headers when fibers are enabled
  * use more accurate names for tests
  * Fix copy-pasto resulting in uninitialized use of kind
  * Fix capnp/capnpc --version when built using CMake
  * Fix feed.xml
* Sun Aug 15 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9
  * There’s no huge new features in this release, but there are
    many minor improvements and bug fixes.
* Mon Apr 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8
  * Multi-stream Flow Control
  * HTTP-over-Cap'n-Proto
  * KJ improvements
  * Lots and lots of minor tweaks and fixes.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Fri Oct 12 2018 Jan Engelhardt <jengelh@inai.de>
- Remove bias from descriptions.
* Fri Oct 12 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.0 (see https://capnproto.org/news)
* Mon Aug 28 2017 aloisio@gmx.com
- Update to stable version 0.6.1
* Thu Mar 30 2017 edogawa@aon.at
- update version 0.6-dev
* Sun Mar 15 2015 i@marguerite.su
- update version 0.5.1.2
* Wed Feb 18 2015 i@marguerite.su
- initial version 0.5.1
